import Header from "@/Components/Header";
import React, { useState, useEffect } from "react";
import Footer from "@/Components/Footer";
import InstagramFeeds from "@/Components/InstagramFeeds";
import { router, usePage, Link, Head } from "@inertiajs/react";
import TrendStories from "@/Components/TrendStories";
import FlashMessages from "@/Components/FlashMessages";
import Button from "@mui/material/Button";
// import AdSense from "react-adsense";

import Icon from "@mdi/react";
import { mdiCalendar, mdiCheckCircleOutline } from "@mdi/js";

import PhoneInput from "react-phone-input-2";
import "react-phone-input-2/lib/material.css";

export default function BlogDetails() {
    const { post, auth, flash } = usePage().props;
    useEffect(() => {}, []);

    const user = auth.user;

    const [loading, setLoading] = useState(false);
    const [name, setName] = useState(user ? user.name : null);
    const [phone, setPhone] = useState(user ? user.phone : null);
    const [email, setEmail] = useState(user ? user.email : null);
    const [message, setMessage] = useState(null);
    const [country, setCountry] = useState(null);

    useEffect(() => {
        setMessage(null);
        setEmail(null);
        setPhone(null);
        setName(null);
        setLoading(false);
    }, [flash]);

    const formatDate = (dateString) => {
        const date = new Date(dateString);
        const options = {
            year: "numeric",
            month: "short",
            day: "2-digit",
            hour: "numeric",
            minute: "2-digit",
            hour12: true,
        };
        return date.toLocaleDateString("en-US", options);
    };
    return (
        <>
            <Head title={`${blog.title.replace(/\s+/g, "-")}`} />

            <FlashMessages />

            <div>
                {/*========== HEADER STYLE ONE START ==========*/}
                <Header fixed={false} />
                {/*========== HEADER STYLE ONE END ==========*/}
                {/*========== HERO STYLE ONE START ==========*/}
                <>
                    <>
                        <>
                            {/*========== BREADCRUMB STYLE START ==========*/}
                            <div className="paralax-container lg:py-36 py-20 relative overflow-hidden">
                                <div
                                    className="jarallax absolute inset-0 z-minus before:content-[''] before:absolute before:inset-0 before:bg-[#030610] before:bg-opacity-50 before:z-minus"
                                    data-jarallax=""
                                >
                                    <img
                                        className="jarallax-img"
                                        src={`/${post.breadcumb_image}`}
                                        alt={post.title}
                                    />
                                </div>
                                <img
                                    src="/assets/images/illustration/breadcrunb__shape.png"
                                    alt="placeholder"
                                    className="absolute bottom-0 left-0 z-1 lg:w-[12.5%] w-[20%]"
                                />
                                <img
                                    src="/assets/images/illustration/bird-illustration-w.png"
                                    alt="placeholder"
                                    className="absolute top-[10%] right-[4%] z-1 w-[7.5%]"
                                />
                                <div className="container relative z-2">
                                    <nav aria-label="breadcrumb">
                                        <ol className="breadcrumb">
                                            <li>
                                                <a href="#">Home</a>
                                            </li>
                                            <li className="active_page">
                                                Blog Post
                                            </li>
                                        </ol>
                                    </nav>
                                    <h2 className="xl:text-[54px] mt-2 lg:text-4xl md:text-2xl text-[30px] text-white leading-[1.3] font-medium max-w-[640px]">
                                        {post.title}
                                    </h2>
                                </div>
                            </div>
                            {/*========== BREADCRUMB STYLE END ==========*/}
                            {/*========== DESTINATION DETAILS WRAPPER START ==========*/}
                            <div className="bg-gradient-to-t to-[#FFF1EC] from-white lg:pt-[110px] pt-[86px] relative z-1">
                                {/* <div className="absolute top-1/2 -translate-y-1/2 right-0 max-w-[14%] z-minus lg:inline-block hidden">
                                    <img
                                        src="/assets/images/illustration/tree-illustration.png"
                                        alt="leaf"
                                    />
                                </div>
                                <div className="absolute top-[5%] left-[1%] max-w-[9%] z-minus lg:inline-block hidden">
                                    <img
                                        src="/assets/images/illustration/bird-illustration.png"
                                        alt="leaf"
                                    />
                                </div> */}
                                <div className="container">
                                    <div className="grid grid-cols-12 gap-base">
                                        <div className="lg:col-span-8 col-span-12">
                                            <div className="blog__details">
                                                <div className="disc__header text-center lg:pb-7 pb-6 border-b border-stock-1 lg:mb-10 mb">
                                                    <div className="disc__thumb overflow-hidden">
                                                        <img
                                                            src={`/${post.image_cover}`}
                                                            alt={post.title}
                                                            className="w-full"
                                                        />
                                                    </div>
                                                    <ul className="flex items-center justify-center lg:text-sm text-xs font-medium text-dark-2 flex-wrap pt-7">
                                                        <li className="flex items-center relative first:pl-0 pl-2 pr-2 before:content-[''] before:absolute before:h-2/3 before:w-[1px] before:bg-dark-2 before:-translate-y-1/2 before:top-1/2 before:left-0 first:before:hidden">
                                                            <Icon
                                                                path={
                                                                    mdiCalendar
                                                                }
                                                                size={0.7}
                                                                className="text-black"
                                                            />
                                                            <span className="ml-2">
                                                                {formatDate(
                                                                    post.date
                                                                )}
                                                            </span>
                                                        </li>
                                                        <li className="flex items-center relative first:pl-0 pl-2 pr-2 before:content-[''] before:absolute before:h-2/3 before:w-[1px] before:bg-dark-2 before:-translate-y-1/2 before:top-1/2 before:left-0 ">
                                                            {post.viewed_times +
                                                                2}{" "}
                                                            View
                                                        </li>
                                                        <li className="flex items-center relative first:pl-0 pl-2 pr-2 before:content-[''] before:absolute before:h-2/3 before:w-[1px] before:bg-dark-2 before:-translate-y-1/2 before:top-1/2 before:left-0 ">
                                                            {post.comments
                                                                .length < 10
                                                                ? "0" +
                                                                  post.comments
                                                                      .length
                                                                : post.comments
                                                                      .length}{" "}
                                                            Comments
                                                        </li>
                                                    </ul>
                                                    <h3 className="text-dark-1 font-medium leading-[1.43] lg:text-2xl md:text-xl text-[28px] mt-[14px]">
                                                        {post.title}
                                                    </h3>
                                                </div>
                                                <div className="disc__wrapper">
                                                    <h5 className="lg:text-2md text-md text-dark-2 font-medium leading-[1.5] font-sans mb-6">
                                                        {post.heading1}
                                                    </h5>
                                                    <p>{post.description1}.</p>
                                                    <p>{post.description2}.</p>
                                                    {/* <AdSense.Google
                                                        client="ca-pub-4460213849771600"
                                                        slot="1421134476"
                                                        style={{
                                                            display: "block",
                                                        }}
                                                        layoutKey="-eb+4z+3v-fw+n2"
                                                        format="fluid"
                                                    />{" "} */}
                                                    {post.quote && (
                                                        <blockquote>
                                                            <p>{post.quote}</p>
                                                            {/* <cite>
                                                            Johan Martin Sr
                                                        </cite> */}
                                                        </blockquote>
                                                    )}
                                                    <h4>{post.title3}</h4>
                                                    <p>{post.description3}</p>
                                                    <div className="grid grid-cols-2 lg:gap-base gap-5 lg:pt-[10px] lg:pb-9 pb-6">
                                                        <div className="col-span-1">
                                                            <img
                                                                src={`/${post.image1}`}
                                                                alt={post.title}
                                                                className="w-full"
                                                            />
                                                        </div>
                                                        <div className="col-span-1">
                                                            <img
                                                                src={`/${post.image2}`}
                                                                alt={post.title}
                                                                className="w-full"
                                                            />
                                                        </div>
                                                    </div>
                                                    <p>{post.description4}</p>
                                                    <ul>
                                                        {post.option1 && (
                                                            <li>
                                                                <Icon
                                                                    path={
                                                                        mdiCheckCircleOutline
                                                                    }
                                                                    size={0.8}
                                                                    className="text-primary-1 text-center mr-2"
                                                                />
                                                                {post.option1}
                                                            </li>
                                                        )}
                                                        {post.option2 && (
                                                            <li>
                                                                <Icon
                                                                    path={
                                                                        mdiCheckCircleOutline
                                                                    }
                                                                    size={0.8}
                                                                    className="text-primary-1 text-center mr-2"
                                                                />
                                                                {post.option2}
                                                            </li>
                                                        )}
                                                        {post.option1 && (
                                                            <li>
                                                                <Icon
                                                                    path={
                                                                        mdiCheckCircleOutline
                                                                    }
                                                                    size={0.8}
                                                                    className="text-primary-1 text-center mr-2"
                                                                />
                                                                {post.option1}
                                                            </li>
                                                        )}
                                                    </ul>
                                                    {post.description5 && (
                                                        <p>
                                                            {post.description5}
                                                        </p>
                                                    )}
                                                    {post.video && (
                                                        <div className="relative mt-[10px] pb-[20px]">
                                                            <img
                                                                src={`/${post.image_cover}`}
                                                                alt={post.title}
                                                                className="w-full"
                                                            />
                                                            <a
                                                                data-fancybox=""
                                                                href={`/${post.video}`}
                                                                className="inline-flex absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 lg:h-20 lg:w-20 h-16 w-16 justify-center items-center rounded-full bg-primary-1 before:content-[''] before:absolute before:-inset-3 before:border-primary-1 before:border-2 before:rounded-full before:animate-pulse"
                                                            >
                                                                <img
                                                                    src="/assets/images/icons/video-circle.svg"
                                                                    alt="placeholder"
                                                                />
                                                            </a>
                                                        </div>
                                                    )}
                                                    <h4>{post.title4}</h4>
                                                    <p>{post.description6}</p>
                                                    <ol className="custom_order__list">
                                                        {post.title5 && (
                                                            <li>
                                                                <span className="list__count">
                                                                    01
                                                                </span>
                                                                <div className="list__content">
                                                                    <h5>
                                                                        {
                                                                            post.title5
                                                                        }
                                                                    </h5>
                                                                    <p>
                                                                        {
                                                                            post.description7
                                                                        }
                                                                    </p>
                                                                </div>
                                                            </li>
                                                        )}
                                                        {post.title6 && (
                                                            <li>
                                                                <span className="list__count">
                                                                    02
                                                                </span>
                                                                <div className="list__content">
                                                                    <h5>
                                                                        {
                                                                            post.title6
                                                                        }
                                                                    </h5>
                                                                    <p>
                                                                        {
                                                                            post.description8
                                                                        }
                                                                    </p>
                                                                </div>
                                                            </li>
                                                        )}
                                                    </ol>
                                                    <p>{post.description8}</p>
                                                </div>
                                                <div className="disc__bottom mt-[10px] lg:pt-6 lg:pb-6 pt-5 pb-5 border-t border-b border-stock-2 flex items-center justify-between flex-wrap gap-3">
                                                    <div className="flex items-center flex-wrap gap-3">
                                                        <h5 className="text-dark-1 lg:text-2md text-md font-semibold">
                                                            Popular Tags:{" "}
                                                        </h5>
                                                        <ul className="flex flex-wrap gap-2">
                                                            <li>
                                                                <a
                                                                    href="#"
                                                                    className="text-dark-3 duration-200 hover:text-primary-1 lg:text-base text-sm font-medium"
                                                                >
                                                                    Travel,
                                                                </a>
                                                            </li>
                                                            <li>
                                                                <a
                                                                    href="#"
                                                                    className="text-dark-3 duration-200 hover:text-primary-1 lg:text-base text-sm font-medium"
                                                                >
                                                                    Hotel,
                                                                </a>
                                                            </li>
                                                            <li>
                                                                <a
                                                                    href="#"
                                                                    className="text-dark-3 duration-200 hover:text-primary-1 lg:text-base text-sm font-medium"
                                                                >
                                                                    Tours
                                                                </a>
                                                            </li>
                                                            <li>
                                                                <a
                                                                    href="#"
                                                                    className="text-dark-3 duration-200 hover:text-primary-1 lg:text-base text-sm font-medium"
                                                                >
                                                                    Tours
                                                                </a>
                                                            </li>
                                                            <li>
                                                                <a
                                                                    href="#"
                                                                    className="text-dark-3 duration-200 hover:text-primary-1 lg:text-base text-sm font-medium"
                                                                >
                                                                    Tours
                                                                </a>
                                                            </li>
                                                        </ul>
                                                    </div>
                                                    <button className="text-dark-2 gap-2 flex items-center lg:text-md text-base hover:text-primary-1 duration-200">
                                                        Share{" "}
                                                        <i className="bi bi-share" />
                                                    </button>
                                                </div>
                                                <div className="pt-10">
                                                    <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] mb-base">
                                                        {post.comments.length <
                                                        10
                                                            ? "0" +
                                                              post.comments
                                                                  .length
                                                            : post.comments
                                                                  .length}{" "}
                                                        Comment’s
                                                    </h3>
                                                    <ul>
                                                        {post.comments.length >
                                                            0 && (
                                                            <>
                                                                {post.comments.map(
                                                                    (
                                                                        item,
                                                                        index
                                                                    ) => {
                                                                        return (
                                                                            <li className="bg-[#FFE3EB] bg-opacity-50 lg:px-base px-5 lg:py-base mt-3 py-5 flex md:flex-row flex-col">
                                                                                <div className="md:mr-5 mb-4 md:mb-0 lg:w-[100px] w-16 rounded-full shrink-0">
                                                                                    <img
                                                                                        src="/avatar.png"
                                                                                        alt="commentor"
                                                                                        className="w-full rounded-full"
                                                                                    />
                                                                                </div>
                                                                                <div className="grow">
                                                                                    <div className="flex justify-between items-center">
                                                                                        <h5 className="text-dark-1 lg:text-2md text-md font-medium !mt-0 !mb-0">
                                                                                            {
                                                                                                item.name
                                                                                            }
                                                                                        </h5>
                                                                                        <a
                                                                                            href="#"
                                                                                            className="flex text-primary-1 gap-[6px] text-xs lg:text-md"
                                                                                        >
                                                                                            Reply
                                                                                        </a>
                                                                                    </div>
                                                                                    <p className="regular-text-v1 lg:mt-3 mt-2 !leading-[1.6] !pb-0">
                                                                                        {
                                                                                            item.message
                                                                                        }

                                                                                        .
                                                                                    </p>
                                                                                </div>
                                                                            </li>
                                                                        );
                                                                    }
                                                                )}
                                                            </>
                                                        )}
                                                    </ul>
                                                </div>
                                                <form
                                                    action="#"
                                                    className="lg:pt-10 pt-8"
                                                >
                                                    <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] !mb-base">
                                                        Post A Comments
                                                    </h3>
                                                    <div className="grid grid-cols-2 gap-base">
                                                        {!auth.user && (
                                                            <>
                                                                <div className="lg:col-span-1 col-span-2">
                                                                    <input
                                                                        type="text"
                                                                        value={
                                                                            name
                                                                        }
                                                                        placeholder="Your Name"
                                                                        onChange={(
                                                                            e
                                                                        ) =>
                                                                            setName(
                                                                                e
                                                                                    .target
                                                                                    .value
                                                                            )
                                                                        }
                                                                        className="input_style__primary"
                                                                    />
                                                                </div>
                                                                <div className="lg:col-span-1 col-span-2">
                                                                    <PhoneInput
                                                                        country={
                                                                            "uk"
                                                                        }
                                                                        enableAreaCodes={
                                                                            true
                                                                        }
                                                                        countryCodeEditable={
                                                                            false
                                                                        }
                                                                        id="phone"
                                                                        autoFormat={
                                                                            false
                                                                        }
                                                                        name="phone"
                                                                        // size="medium"
                                                                        value={
                                                                            phone
                                                                        }
                                                                        inputStyle={{
                                                                            width: "100%",
                                                                            height: "11px",
                                                                            background:
                                                                                "none",
                                                                        }}
                                                                        onChange={(
                                                                            e
                                                                        ) => {
                                                                            setPhone(
                                                                                e
                                                                            );
                                                                        }}
                                                                        enableSearch={
                                                                            true
                                                                        }
                                                                        inputProps={{
                                                                            name: "phone",
                                                                            // size: "large",
                                                                            required: true,
                                                                            autoFocus: true,
                                                                        }}
                                                                        isValid={(
                                                                            value,
                                                                            country
                                                                        ) => {
                                                                            if (
                                                                                value.match(
                                                                                    /12345/
                                                                                )
                                                                            ) {
                                                                                return (
                                                                                    "Invalid value: " +
                                                                                    value +
                                                                                    ", " +
                                                                                    country.name
                                                                                );
                                                                            } else if (
                                                                                value.match(
                                                                                    /12345/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else if (
                                                                                value.match(
                                                                                    /1111111/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else if (
                                                                                value.match(
                                                                                    /000000/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else {
                                                                                setCountry(
                                                                                    country.name
                                                                                );
                                                                                return true;
                                                                            }
                                                                        }}
                                                                    />
                                                                </div>
                                                                <div className="col-span-2">
                                                                    <input
                                                                        type="email"
                                                                        value={
                                                                            email
                                                                        }
                                                                        onChange={(
                                                                            e
                                                                        ) =>
                                                                            setEmail(
                                                                                e
                                                                                    .target
                                                                                    .value
                                                                            )
                                                                        }
                                                                        placeholder="Your Email"
                                                                        className="input_style__primary"
                                                                    />
                                                                </div>
                                                            </>
                                                        )}
                                                        <div className="col-span-2">
                                                            <textarea
                                                                cols={30}
                                                                value={message}
                                                                rows={6}
                                                                onChange={(e) =>
                                                                    setMessage(
                                                                        e.target
                                                                            .value
                                                                    )
                                                                }
                                                                className="input_style__primary"
                                                                placeholder="Your Message..."
                                                                defaultValue={
                                                                    ""
                                                                }
                                                            />
                                                        </div>
                                                        <div className="col-span-2">
                                                            {loading ? (
                                                                <Button
                                                                    variant="contained"
                                                                    disabled={
                                                                        true
                                                                    }
                                                                >
                                                                    Posting...
                                                                </Button>
                                                            ) : (
                                                                <button
                                                                    type="submit"
                                                                    onClick={(
                                                                        e
                                                                    ) => {
                                                                        e.preventDefault();
                                                                        setLoading(
                                                                            true
                                                                        );
                                                                        // console.log({
                                                                        //     package_id:
                                                                        //         tourPackage.id,
                                                                        //     name,
                                                                        //     email,
                                                                        //     phone,
                                                                        //     message,
                                                                        // });
                                                                        router.post(
                                                                            "/post-comment",
                                                                            {
                                                                                blog_id:
                                                                                    post.id,
                                                                                name,
                                                                                email,
                                                                                phone,
                                                                                message,
                                                                            }
                                                                        );
                                                                    }}
                                                                    className="btn_primary__v1"
                                                                    // disabled={true}
                                                                >
                                                                    Post
                                                                    {/* <i className="bi bi-chevron-right" /> */}
                                                                </button>
                                                            )}
                                                        </div>
                                                    </div>
                                                </form>
                                            </div>
                                        </div>
                                        <TrendStories />
                                    </div>
                                </div>
                            </div>
                            {/*========== DESTINATION DETAILS WRAPPER END ==========*/}
                        </>
                    </>
                </>
                {/*========== INSTAGRAM FEED STYLE START ==========*/}
                {/* <InstagramFeeds /> */}
                {/*========== INSTAGRAM FEED STYLE END ==========*/}
                {/*========== FOOTER STYLE START ==========*/}
                {/* <AdSense.Google
                    client="ca-pub-4460213849771600"
                    slot="1421134476"
                    style={{
                        display: "block",
                    }}
                    layoutKey="-eb+4z+3v-fw+n2"
                    format="fluid"
                />{" "} */}
                <Footer />
                {/*========== FOOTER STYLE END ==========*/}
            </div>
        </>
    );
}
